@@ -2,6 +2,7 @@ package MooX::Const;
 
 # ABSTRACT: Syntactic sugar for creating constant Moo attributes
 
+use utf8;
 use v5.8;
 
 use Carp qw( croak );
@@ -13,7 +14,7 @@ use Types::Standard qw( Value Object Ref );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.3';
 
 
 sub import {
@@ -91,7 +92,7 @@ MooX::Const - Syntactic sugar for creating constant Moo attributes
 
 =head1 VERSION
 
-version v0.1.2
+version v0.1.3
 
 =head1 SYNOPSIS
 
@@ -155,6 +156,15 @@ feature.
 
 Robert Rothenberg <rrwo@cpan.org>
 
+This module was inspured by suggestions from Kang-min Liu 劉康民
+<gugod@gugod.org> in a L<blog post|http://blogs.perl.org/users/robert_rothenberg/2018/11/typeconst-released.html>.
+
+=head1 CONTRIBUTOR
+
+=for stopwords Kang-min Liu 劉康民
+
+Kang-min Liu 劉康民 <gugod@gugod.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2018 by Robert Rothenberg.
